Hourly — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »

# Hourly

Get weather data, process it, prepare graphs & text files and upload to a web site.

Typically run every hour from cron.

    usage: python -m pywws.Hourly [options] data_dir
    options are:
     -h or --help     display this help
     -v or --verbose  increase amount of reassuring messages
    data_dir is the root directory of the weather data (e.g. $(HOME)/weather/data)

This script does little more than call other modules in sequence to get data from the weather station, process it, plot some graphs, generate some text files and upload the results to a web site.

For more information on using `Hourly.py`, see How to set up ‘hourly’ logging with pywws.

Functions

`Hourly`(data_dir) |
`main`([argv]) |

`pywws.Hourly.` `Hourly`(data_dir)

`pywws.Hourly.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »